// sendc
// xmodem receive utility

#include "xmodem.h"

extern struct global
{ 
  volatile unsigned char *recv_ptr; 
  volatile unsigned char buffer_status;
  volatile unsigned char recv_error;
  volatile unsigned char t1_timed_out;
} gl;

void sendc(void) {

    // 3 second timeout
    // 7.3728MHz / 1024 = 7200 Hz
    // 7200 Hz = 138.8 us
    // 3 seconds / 138.8 us = 21600
    // 65536 - 21600 = 43936 = aba0
    // interrupt on ffff to 0000 transition
    TCNT1H = 0xab;
    TCNT1L = 0xa0; // load counter
    TCCR1B = 0x00; // disable timer/counter 1 clock
    
    // enable entry into while loops
    gl.buffer_status = empty;
    gl.t1_timed_out = false;
    gl.recv_error = false; // checked in validate_packet for framing or overruns
     
    // send character 'C' until we get a packet from the sender
    while (!gl.buffer_status) 
    {
        // tell sender CRC mode
        while (!(USR & 0x20)); // wait till Data register is empty
        UDR = CRCCHR; // signal transmitter that I'm ready in CRC mode ... 128 byte packets
        TCCR1B = 0x05; // timer/counter 1 clock / 1024

        // wait for timeout or recv buffer to fill
        while (!gl.t1_timed_out && !gl.buffer_status);
 
                                    // turn off timer
        TCCR1B = 0x00;              // disable timer/counter 1 clock
 
        if (gl.t1_timed_out)                  // start wait loop again
        { 
            gl.t1_timed_out = false;
            TCNT1H = 0xab;  
            TCNT1L = 0xa0;            // load counter ... start over
        }
     }
}
